summaryrefslogtreecommitdiff
path: root/nest/route.h
diff options
context:
space:
mode:
Diffstat (limited to 'nest/route.h')
-rw-r--r--nest/route.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/nest/route.h b/nest/route.h
index 3c10fc55..177baa38 100644
--- a/nest/route.h
+++ b/nest/route.h
@@ -221,13 +221,13 @@ typedef struct rte {
} rte;
#define REF_COW 1 /* Copy this rte on write */
-#define REF_REJECTED 2 /* Route is rejected by import filter */
+#define REF_FILTERED 2 /* Route is rejected by import filter */
/* Route is valid for propagation (may depend on other flags in the future), accepts NULL */
-static inline int rte_is_valid(rte *r) { return r && !(r->flags & REF_REJECTED); }
+static inline int rte_is_valid(rte *r) { return r && !(r->flags & REF_FILTERED); }
-/* Route just has REF_REJECTED flag */
-static inline int rte_is_rejected(rte *r) { return !!(r->flags & REF_REJECTED); }
+/* Route just has REF_FILTERED flag */
+static inline int rte_is_filtered(rte *r) { return !!(r->flags & REF_FILTERED); }
/* Types of route announcement, also used as flags */
@@ -271,7 +271,7 @@ struct rt_show_data {
struct fib_iterator fit;
struct proto *show_protocol;
struct proto *export_protocol;
- int export_mode, primary_only, rejected;
+ int export_mode, primary_only, filtered;
struct config *running_on_config;
int net_counter, rt_counter, show_counter;
int stats, show_for;